@@ -14,7 +14,6 @@ fixtures are available.
 """
 
 import pytest
-from flask_principal import Identity, Need, UserNeed
 from invenio_records_resources.services.files import FileService
 from mock_module.api import Draft
 from mock_module.service import FileServiceConfig, ServiceConfig
@@ -22,15 +21,6 @@ from mock_module.service import FileServiceConfig, ServiceConfig
 from invenio_drafts_resources.services.records import RecordService
 
 
-@pytest.fixture(scope="module")
-def identity_simple():
-    """Simple identity fixture."""
-    i = Identity(1)
-    i.provides.add(UserNeed(1))
-    i.provides.add(Need(method='system_role', value='any_user'))
-    return i
-
-
 @pytest.fixture()
 def service(appctx, location):
     """Service instance."""
